==> openjdk-12_12.0.2+9.orig.tar.xz: openjdk-12-12.0.2+9/src/hotspot/share/jfr/recorder/repository/jfrChunkRotation.hpp <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_VM_JFR_RECORDER_REPOSITORY_JFRCHUNKROTATION_HPP
#define SHARE_VM_JFR_RECORDER_REPOSITORY_JFRCHUNKROTATION_HPP

#include "memory/allocation.hpp"

class JfrChunkWriter;

//
// Responsible for notifications about current chunk size now exceeding threshold.
// This is a means to initiate a chunk rotation on the basis of the size written.
//
class JfrChunkRotation : AllStatic {
 public:
  static void evaluate(const JfrChunkWriter& writer);
  static void set_threshold(int64_t bytes);
  static bool should_rotate();
  static void on_rotation();
};

#endif // SHARE_VM_JFR_RECORDER_REPOSITORY_JFRCHUNKROTATION_HPP

==> openjdk-17_17.0.17+10.orig.tar.xz: openjdk-17-17.0.17+10/src/hotspot/share/jfr/recorder/repository/jfrChunkRotation.hpp <==
/*
 * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_JFR_RECORDER_REPOSITORY_JFRCHUNKROTATION_HPP
#define SHARE_JFR_RECORDER_REPOSITORY_JFRCHUNKROTATION_HPP

#include "memory/allocation.hpp"

class JfrChunkWriter;

//
// Responsible for notifications about current chunk size now exceeding threshold.
// This is a means to initiate a chunk rotation on the basis of the size written.
//
class JfrChunkRotation : AllStatic {
 public:
  static void evaluate(const JfrChunkWriter& writer);
  static void set_threshold(int64_t bytes);
  static bool should_rotate();
  static void on_rotation();
};

#endif // SHARE_JFR_RECORDER_REPOSITORY_JFRCHUNKROTATION_HPP
